package com.antwerkz.sofia;

import java.text.*;
import java.util.*;

public class Localizer {
    private static Map<Locale, ResourceBundle> messages = new HashMap<Locale, ResourceBundle>();

    private static ResourceBundle getBundle(Locale... localeList) {
        Locale locale = localeList.length == 0 ? Locale.getDefault() : localeList[0];
        ResourceBundle labels = loadBundle(locale);
        if(labels == null) {
            labels = loadBundle(Locale.ROOT);
        }
        return labels;
    }

    private static ResourceBundle loadBundle(Locale locale) {
        ResourceBundle bundle = messages.get(locale);
        if(bundle == null) {
            bundle = ResourceBundle.getBundle("sofia", locale);
            messages.put(locale, bundle);
        }
        return bundle;
    }

    private static String getMessageValue(String key, Locale... locale) {
        return (String) getBundle(locale).getObject(key);
    }

    public static String dateProperty(java.util.Date arg0, Number arg1, Locale... locale) {
        return MessageFormat.format(getMessageValue("date.property", locale), arg0, arg1);
    }

    public static String newProperty(Locale... locale) {
        return getMessageValue("new.property", locale);
    }

    public static String parameterizedPropertyLongName(Object arg0, Object arg1, Locale... locale) {
        return MessageFormat.format(getMessageValue("parameterized.property.long.name", locale), arg0, arg1);
    }

    public static String testProperty(Locale... locale) {
        return getMessageValue("test.property", locale);
    }

}
